AppBarWithSearch

Function AppBarWithSearch 

pub fn AppBarWithSearch(
    state: Rc<SearchBarState>,
    input_field: View,
    navigation_icon: Option<View>,
    actions: Option<Vec<View>>,
    config: AppBarWithSearchConfig,
) -> View
M3 App Bar With Search -> integrates a search bar into a top app bar layout with optional navigation icon, action buttons, scroll behavior, and window insets. Wraps the internal SearchBar collapsed component.