pub fn BadgedBox(badge: View, content: View, config: BadgedBoxConfig) -> ViewExpand description
Wraps content and shows a badge anchored to the top-end corner.
pub fn BadgedBox(badge: View, content: View, config: BadgedBoxConfig) -> ViewWraps content and shows a badge anchored to the top-end corner.