pub struct BadgedBoxConfig {
pub modifier: Modifier,
pub dot_offset_x: f32,
pub dot_offset_y: f32,
pub content_offset_x: f32,
pub content_offset_y: f32,
}Expand description
Configuration for BadgedBox.
Fields
modifier: Modifierdot_offset_x: f32Horizontal offset for the badge when it’s a small dot.
dot_offset_y: f32Vertical offset for the badge when it’s a small dot.
content_offset_x: f32Horizontal offset for the badge when it has content.
content_offset_y: f32Vertical offset for the badge when it has content.